"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_i18next_1 = require("react-i18next");
const Config_1 = require("../../utilities/Config");
const Button_1 = __importDefault(require("../Button"));
const DocumentInfo_1 = require("../../utilities/DocumentInfo");
const shouldIncrementVersionCount_1 = require("../../../../versions/shouldIncrementVersionCount");
require("./index.scss");
const baseClass = 'versions-count';
const VersionsCount = ({ collection, global, id }) => {
    var _a, _b, _c;
    const { routes: { admin } } = (0, Config_1.useConfig)();
    const { versions, publishedDoc, unpublishedVersions } = (0, DocumentInfo_1.useDocumentInfo)();
    const { t } = (0, react_i18next_1.useTranslation)('version');
    // Doc status could come from three places:
    // 1. the newest unpublished version (a draft)
    // 2. the published doc's status, in the event that the doc is published and there are no newer versions
    // 3. if there is no published doc, it's a draft
    const docStatus = ((_c = (_b = (_a = unpublishedVersions === null || unpublishedVersions === void 0 ? void 0 : unpublishedVersions.docs) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.version) === null || _c === void 0 ? void 0 : _c._status) || (publishedDoc === null || publishedDoc === void 0 ? void 0 : publishedDoc._status) || 'draft';
    let versionsURL;
    let entity;
    if (collection) {
        versionsURL = `${admin}/collections/${collection.slug}/${id}/versions`;
        entity = collection;
    }
    if (global) {
        versionsURL = `${admin}/globals/${global.slug}/versions`;
        entity = global;
    }
    let initialVersionsCount = 0;
    if ((0, shouldIncrementVersionCount_1.shouldIncrementVersionCount)({ entity, versions, docStatus })) {
        initialVersionsCount = 1;
    }
    const versionCount = ((versions === null || versions === void 0 ? void 0 : versions.totalDocs) || 0) + initialVersionsCount;
    return (react_1.default.createElement("div", { className: baseClass },
        versionCount === 0 && t('versionCount_none'),
        versionCount > 0 && (react_1.default.createElement(Button_1.default, { className: `${baseClass}__button`, buttonStyle: "none", el: "link", to: versionsURL }, t(versionCount === 1 ? 'versionCount_one' : 'versionCount_many', { count: versionCount })))));
};
exports.default = VersionsCount;
//# sourceMappingURL=index.js.map